@@ -1,6 +1,6 @@
 /*
  * hbytes - hex-stringrep efficient byteblocks for Tcl
- * Copyright 2006 Ian Jackson
+ * Copyright 2006-2012 Ian Jackson
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -13,9 +13,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301, USA.
+ * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -73,6 +71,7 @@ void cht_obj_updatestr_array_prefix(Tcl_Obj *o, const Byte *byte,
   int pl;
 
   pl= strlen(prefix);
+  assert(l < INT_MAX/2 - 1 - pl);
   o->length= l*2+pl;
   str= o->bytes= TALLOC(o->length+1);
   
@@ -97,8 +96,8 @@ static void hbytes_t_ustr(Tcl_Obj *o) {
 }
 
 static int hbytes_t_sfa(Tcl_Interp *ip, Tcl_Obj *o) {
-  char *str, *ep, *os;
-  Byte *startbytes, *bytes;
+  char *str, *ep;
+  Byte *bytes;
   int l;
   char cbuf[3];
 
@@ -110,13 +109,13 @@ static int hbytes_t_sfa(Tcl_Interp *ip, Tcl_Obj *o) {
 
   } else {
   
-    os= str= Tcl_GetStringFromObj(o,&l);  assert(str);
+    str= Tcl_GetStringFromObj(o,&l);  assert(str);
     cht_objfreeir(o);
 
     if (l & 1) return cht_staticerr(ip, "hbytes: conversion from hex:"
 				" odd length in hex", "HBYTES SYNTAX");
 
-    startbytes= bytes= cht_hb_arrayspace(OBJ_HBYTES(o), l/2);
+    bytes= cht_hb_arrayspace(OBJ_HBYTES(o), l/2);
 
     cbuf[2]= 0;
     while (l>0) {
